@@ -26,7 +26,6 @@ import (
 	"github.com/bep/logg"
 	"github.com/gohugoio/httpcache"
 	hhttpcache "github.com/gohugoio/hugo/cache/httpcache"
-	"github.com/gohugoio/hugo/helpers"
 	"github.com/gohugoio/hugo/hugofs/glob"
 	"github.com/gohugoio/hugo/identity"
 
@@ -34,6 +33,7 @@ import (
 
 	"github.com/gohugoio/hugo/cache/dynacache"
 	"github.com/gohugoio/hugo/cache/filecache"
+	"github.com/gohugoio/hugo/common/hashing"
 	"github.com/gohugoio/hugo/common/hcontext"
 	"github.com/gohugoio/hugo/common/hugio"
 	"github.com/gohugoio/hugo/common/tasks"
@@ -143,16 +143,18 @@ func (c *Client) Get(pathname string) (resource.Resource, error) {
 			return nil, err
 		}
 
-		pi := fi.(hugofs.FileMetaInfo).Meta().PathInfo
+		meta := fi.(hugofs.FileMetaInfo).Meta()
+		pi := meta.PathInfo
 
 		return c.rs.NewResource(resources.ResourceSourceDescriptor{
 			LazyPublish: true,
 			OpenReadSeekCloser: func() (hugio.ReadSeekCloser, error) {
 				return c.rs.BaseFs.Assets.Fs.Open(filename)
 			},
-			Path:          pi,
-			GroupIdentity: pi,
-			TargetPath:    pathname,
+			Path:                 pi,
+			GroupIdentity:        pi,
+			TargetPath:           pathname,
+			SourceFilenameOrPath: meta.Filename,
 		})
 	})
 }
@@ -196,10 +198,11 @@ func (c *Client) match(name, pattern string, matchFunc func(r resource.Resource)
 				OpenReadSeekCloser: func() (hugio.ReadSeekCloser, error) {
 					return meta.Open()
 				},
-				NameNormalized: meta.PathInfo.Path(),
-				NameOriginal:   meta.PathInfo.Unnormalized().Path(),
-				GroupIdentity:  meta.PathInfo,
-				TargetPath:     meta.PathInfo.Unnormalized().Path(),
+				NameNormalized:       meta.PathInfo.Path(),
+				NameOriginal:         meta.PathInfo.Unnormalized().Path(),
+				GroupIdentity:        meta.PathInfo,
+				TargetPath:           meta.PathInfo.Unnormalized().Path(),
+				SourceFilenameOrPath: meta.Filename,
 			})
 			if err != nil {
 				return true, err
@@ -226,7 +229,7 @@ func (c *Client) match(name, pattern string, matchFunc func(r resource.Resource)
 // TODO(bep) see #10912; we currently emit a warning for this config scenario.
 func (c *Client) FromString(targetPath, content string) (resource.Resource, error) {
 	targetPath = path.Clean(targetPath)
-	key := dynacache.CleanKey(targetPath) + helpers.MD5String(content)
+	key := dynacache.CleanKey(targetPath) + hashing.MD5FromStringHexEncoded(content)
 	r, err := c.rs.ResourceCache.GetOrCreate(key, func() (resource.Resource, error) {
 		return c.rs.NewResource(
 			resources.ResourceSourceDescriptor{
